const path = require('path');

// load the default config generator.
const genDefaultConfig = require('@storybook/react/dist/server/config/defaults/webpack.config.js');
const testCssRule = "" + /\.css$/;
const testCssLoaderRx = /\bcss-loader\b/

module.exports = (baseConfig, env) => {
    const config = genDefaultConfig(baseConfig, 'development');

    // add alias
    config.resolve = config.resolve || {}
    config.resolve.alias = config.resolve.alias || {};
    config.resolve.alias["@node_modules"] = path.resolve(__dirname, "../node_modules");
    config.resolve.alias["@src"] = path.resolve(__dirname, "../src");
    config.resolve.alias["@api"] = path.resolve(__dirname, "../api");

    // CSS MODLUDES
    let cssRule = config.module.rules.find((r) => "" + r.test == testCssRule);
    if (cssRule) {
        let cssModules = cssRule.use.find((l) => testCssLoaderRx.test(l.loader));
        if (cssModules) {
            cssModules.options = cssModules.options || {};
            cssModules.options.modules = true;
            cssModules.options.sourceMap = true;
            cssModules.options.importLoaders = 1;
            cssModules.options.localIdentName = "[name]--[local]--[hash:base64:8]"
        }
    }

    // typescript
    config.module.rules.push({
        test: /\.(ts|tsx)$/,
        loader: require.resolve('ts-loader'),
        include: path.resolve(__dirname, '../')
    });
    config.resolve.extensions.push('.ts', '.tsx');

    // SASS
    config.module.rules.push({
        test: /\.scss$/,
        loaders: ["style-loader", "css-loader", "sass-loader"],
        include: path.resolve(__dirname, '../')
    });

    return config;
};